@@ -44,6 +44,9 @@ SERVICE_CONTROL_POLICY = "service-control-policy"
 TAG_POLICIES = "tag-policies"
 TAG_POLICY = "tag-policy"
 
+ORGANIZATIONAL_UNIT = "organizational-unit"
+ORGANIZATIONAL_UNITS = "organizational-units"
+
 SIMULATE_POLICIES = "simulate-policies"
 SIMULATE_POLICY = "simulate-policy"
 
@@ -174,6 +177,7 @@ ALL_SECTION_NAME_SINGULAR_AND_PLURAL_LIST = [
     (SERVICE_CONTROL_POLICY, SERVICE_CONTROL_POLICIES),
     (SIMULATE_POLICY, SIMULATE_POLICIES),
     (TAG_POLICY, TAG_POLICIES),
+    (ORGANIZATIONAL_UNIT, ORGANIZATIONAL_UNITS),
 ]
 
 SECTION_NAME_SINGULAR_AND_PLURAL_LIST_THAT_SUPPORTS_PARAMETERS = [
@@ -374,3 +378,6 @@ RUN_DEPLOY_IN_SPOKE_BUILDSPEC = """
 """
 
 SCHEDULER_THREADS_OR_PROCESSES_DEFAULT = "threads"
+
+
+REPORTING_ROLE_NAME = "PuppetRoleForReporting"
