@@ -148,6 +148,7 @@ ORGANIZATIONS_DESCRIBE_POLICIES_PER_REGION = (
     "ORGANIZATIONS_DESCRIBE_POLICIES" + PER_REGION
 )
 ORGANIZATIONS_UPDATE_POLICIES_PER_REGION = "ORGANIZATIONS_UPDATE_POLICIES" + PER_REGION
+ORGANIZATIONS_CREATE_OU = "ORGANIZATIONS_CREATE_POLICIES"
 
 IAM_SIMULATE_POLICY_PER_REGION_OF_ACCOUNT = (
     "IAM_SIMULATE_POLICY_{simulation_type}" + PER_REGION_OF_ACCOUNT
@@ -474,6 +475,11 @@ def create(section_name, parameters_to_use, puppet_account_id):
             CLOUDFORMATION_CREATE_OR_UPDATE_PER_REGION_OF_ACCOUNT,
         ]
 
+    elif section_name == constants.ORGANIZATIONAL_UNITS:
+        resources = [
+            ORGANIZATIONS_CREATE_OU,
+        ]
+
     else:
         raise Exception(f"Unknown section_name: {section_name}")
 
