@@ -771,5 +771,19 @@ def create(
             accounts_to_share_with=parameters_to_use.get("accounts_to_share_with"),
         )
 
+    elif section_name == constants.ORGANIZATIONAL_UNITS:
+        from servicecatalog_puppet.workflow.organizational_units import (
+            get_or_create_organizational_unit_task,
+        )
+
+        return get_or_create_organizational_unit_task.GetOrCreateOrganizationalUnitTask(
+            **common_parameters,
+            path=parameters_to_use.get("path"),
+            parent_ou_id=parameters_to_use.get("parent_ou_id"),
+            name=parameters_to_use.get("name"),
+            tags=parameters_to_use.get("tags"),
+            parent_ou_task_ref=parameters_to_use.get("parent_ou_task_ref"),
+        )
+
     else:
         raise Exception(f"Unknown section_name: {section_name}")
